Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Handler ¶ added in v0.24.0
func Handler() fox.HandlerFunc
Handler returns a HandlerFunc that responds with detailed system, router and request information. This function may leak sensitive information and is only useful for debugging purposes, providing a comprehensive overview of the incoming request and the system it is running on.
func HandlerWith ¶ added in v0.24.0
func HandlerWith(f *fox.Router) fox.HandlerFunc
HandlerWith returns a HandlerFunc that responds with detailed system, router and request information using the provided router instance. This function may leak sensitive information and is only useful for debugging purposes, providing a comprehensive overview of the incoming request and the system it is running on.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.